@@ -1,13 +1,16 @@
 """goaling.py goal action module
 
 """
-#print "module %s" % __name__
+#print("module {0}".format(__name__))
 
 import time
 import struct
 
 from collections import deque
-from itertools import izip
+try:
+    from itertools import izip
+except ImportError: # python3
+    izip = zip
 
 import inspect
 
@@ -18,7 +21,7 @@ from .odicting import odict
 from . import aiding
 from . import excepting
 from . import registering
-from . import storing 
+from . import storing
 from . import acting
 
 from .consoling import getConsole
@@ -45,13 +48,13 @@ class Goal(acting.Actor):
         if 'preface' not in kw:
             kw['preface'] = 'Goal'
 
-        super(Goal,self).__init__(**kw)  
+        super(Goal,self).__init__(**kw)
 
     def expose(self):
         """
 
         """
-        print "Goal %s" % (self.name)
+        print("Goal %s" % (self.name))
 
 
 #Direct goal
@@ -62,10 +65,6 @@ class DirectGoal(Goal):
     def __init__(self, **kw):
         """Initialization method for instance.
 
-           inherited attributes:
-              .name = unique name for action instance
-              .store = shared data store
-
            parameters:
               goal = share of goal
               data = dict of data fields to assign to goal share
@@ -75,7 +74,7 @@ class DirectGoal(Goal):
         super(DirectGoal, self).__init__(**kw)  #.goal inited here
 
 
-    def action(self, goal, data, **kw): 
+    def action(self, goal, data, **kw):
         """Set goal to data dictionary"""
 
         console.profuse("Set {0} to {1}\n".format(goal.name, data))
@@ -90,10 +89,6 @@ class IndirectGoal(Goal):
     def __init__(self, **kw):
         """Initialization method for instance.
 
-           inherited attributes:
-              .name = unique name for action instance
-              .store = shared data store
-
            parameters:
               goal = share of goal
               source = share of source to get data from
@@ -104,7 +99,7 @@ class IndirectGoal(Goal):
         super(IndirectGoal, self).__init__(**kw)  #.goal inited here
 
 
-    def action(self, goal, goalFields, source, sourceFields, **kw): 
+    def action(self, goal, goalFields, source, sourceFields, **kw):
         """Set goalFields in goal from sourceFields in source"""
 
         console.profuse("Set {0} in {1} from {2} in {3}\n".format(
